import { ReactNode } from "react";
import { BrowserRouter } from "react-router-dom";
import { ChakraProvider } from "@chakra-ui/react";
import useInitHooks from "@src/hooks/init-hooks";
import theme from "@src/util/theme";
import { AuthProvider } from "@src/ctx/AuthContext";
import Viewport from "./Viewport";
import { ProjectProvider } from "./ctx/ProjectContext";
import { QueryClient, QueryClientProvider } from "@tanstack/react-query";
import "react-toastify/dist/ReactToastify.css";

export default function App() {
  const qc = new QueryClient();
  return (
    <ChakraProvider theme={theme}>
      <BrowserRouter>
        <QueryClientProvider client={qc}>
          <AuthProvider>
            <ProjectProvider>
              <InitProvider>
                <Viewport />
              </InitProvider>
            </ProjectProvider>
          </AuthProvider>
        </QueryClientProvider>
      </BrowserRouter>
    </ChakraProvider>
  );
}

function InitProvider(props: { children: ReactNode }) {
  useInitHooks();
  return props.children;
}
