import { Flex, Text, Center, Box, Skeleton, Stack } from "@chakra-ui/react";
import ProjectTile, { ProjectTileSkeleton } from "@src/components/projects/ProjectTile";
import { useProjectContext } from "@src/ctx/ProjectContext";
import { useProjectList } from "@src/util/api/queries";
import { GuardedContent } from "@src/util/guards";
import { ReactNode } from "react";

const skeletonCount = 12;
const loadingFallbacks: ReactNode[] = new Array(skeletonCount)
  .fill(0)
  .map((_v: number, i: number) => <ProjectTileSkeleton key={i} />);

export default function ProjectView() {
  const { projectId } = useProjectContext();
  const { data, isLoading } = useProjectList(projectId);
  const projects = (data?.childProjects ?? []).filter((p) => p.id !== data?.project.id);
  return (
    <Box h="calc(100vh - 1.5rem)" w="100%" overflowY={isLoading ? "hidden" : "unset"}>
      <Flex wrap="wrap" m="1.5rem" gap="2rem">
        <Flex wrap="wrap" w="100%">
          <Text fontSize="18px" h="2rem" w="100%" fontWeight={800}>
            Project
          </Text>
          <Center w="100%">
            {isLoading && <ProjectTileSkeleton />}
            {!!data?.project && <ProjectTile project={data?.project} />}
          </Center>
        </Flex>

        <GuardedContent guard={projects.length > 0}>
          <Flex wrap="wrap" w="100%">
            <Text fontSize="18px" h="2rem" w="100%" fontWeight={800}>
              Child Projects
            </Text>
            <Center gap="2rem" flexWrap="wrap" w="100%">
              {isLoading && loadingFallbacks}
              {projects.map((p) => (
                <ProjectTile key={p.id} project={p} />
              ))}
            </Center>
          </Flex>
        </GuardedContent>

        <GuardedContent guard={projects.length === 0}>
          <Flex h="40vh" w="100%">
            <Center w="100%" flexWrap="wrap">
              <Box bg="background.paper" p="1.75rem" borderRadius=".5rem">
                <Text w="100%" textAlign="center">
                  No child projects found!
                </Text>
                <Text w="100%" textAlign="center">
                  Create one by clicking here
                </Text>
              </Box>
            </Center>
          </Flex>
        </GuardedContent>
      </Flex>
    </Box>
  );
}
